@@ -1,6 +1,6 @@
 package App::PerlWatcher::Engine;
 {
-  $App::PerlWatcher::Engine::VERSION = '0.18';
+  $App::PerlWatcher::Engine::VERSION = '0.19';
 }
 # ABSTRACT: Creates Watchers and lets them  notify Frontend with their's Statuses
 
@@ -13,8 +13,9 @@ use Carp;
 use Class::Load ':all';
 use Smart::Comments -ENV;
 use File::Spec;
+use List::MoreUtils qw/first_index/;
 use Moo;
-use Path::Class qw(file);
+use Path::Tiny;
 
 use App::PerlWatcher::Shelf;
 use App::PerlWatcher::Util::Bootstrap qw/get_home_dir/;
@@ -23,6 +24,7 @@ use App::PerlWatcher::Util::Storable qw/freeze thaw/;
 
 
 
+
 has 'frontend'          => ( is => 'rw');
 
 
@@ -32,13 +34,16 @@ has 'backend'           => ( is => 'ro', required => 1);
 
 
 has 'statuses_file'     => ( is => 'ro', default => sub {
-        return file(File::Spec->catfile(get_home_dir(), "statuses-shelf.data"));
+        return path(File::Spec->catfile(get_home_dir(), "statuses-shelf.data"));
     });
 
 
 has 'watchers'          => ( is => 'lazy');
 
 
+has 'polling_watchers' => ( is => 'ro', default => sub{ [] });
+
+
 has 'watchers_order'    => ( is => 'lazy');
 
 
@@ -48,8 +53,16 @@ sub _build_watchers {
     my $self = shift;
     my $config = $self->config;
     my @r;
+    my $poll_callback = sub {
+        my $w = shift;
+        push @{ $self->polling_watchers }, $w;
+        $self->frontend->poll($w);
+    };
     my $engine_callback = sub {
         my $status = shift;
+        my $w_idx = first_index { $_->unique_id eq $status->watcher->unique_id }
+            @{ $self->polling_watchers };
+        splice( @{ $self->polling_watchers }, $w_idx, 1);
         AnyEvent::postpone {
             $self->frontend->update($status);
         };
@@ -63,6 +76,7 @@ sub _build_watchers {
             $watcher = $class->new(
                 engine_config => $config,
                 callback      => $engine_callback,
+                poll_callback => $poll_callback,
                 %$watcher_config
             );
             $watcher->callback($engine_callback);
@@ -138,7 +152,7 @@ App::PerlWatcher::Engine - Creates Watchers and lets them  notify Frontend with
 
 =head1 VERSION
 
-version 0.18
+version 0.19
 
 =head1 SYNOPSIS
 
@@ -239,6 +253,10 @@ $HOME/.perl-watcher/statuses-shelf.data
 An array_ref of Watcher instances. Watchers order is the same as it was
 defined in config
 
+=head2 polling_watchers
+
+An array_ref of Watcher instances, which currently do poll of external resource
+
 =head2 watchers_order
 
 Return an map "watcher to watcher order".
@@ -265,6 +283,12 @@ and shelf)
 Helper method which sorts statuses in accordance with theirs watchers
 order
 
+=head1 GTK2 FRONTEND SCREENSHOT
+
+=for HTML <p>
+<img src="https://raw.github.com/basiliscos/images/master/PerlWatcher-0.16.png" alt="PerlWatcher GTK2 screenshot" title="PerlWatcher GTK2 screenshot" style="max-width:100%;">
+</p>
+
 =head1 CREDITS
 
 =over 2
